@@ -13,17 +13,17 @@
 #include <jansson_private_config.h>
 #endif
 
+#include <math.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
 
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
 
-#include "jansson.h"
 #include "hashtable.h"
+#include "jansson.h"
 #include "jansson_private.h"
 #include "utf.h"
 
@@ -37,21 +37,29 @@ static JSON_INLINE int isnan(double x) { return x != x; }
 static JSON_INLINE int isinf(double x) { return !isnan(x) && isnan(x - x); }
 #endif
 
-static JSON_INLINE void json_init(json_t *json, json_type type)
-{
+json_t *do_deep_copy(const json_t *json, hashtable_t *parents);
+
+static JSON_INLINE void json_init(json_t *json, json_type type) {
     json->type = type;
     json->refcount = 1;
 }
 
+int jsonp_loop_check(hashtable_t *parents, const json_t *json, char *key,
+                     size_t key_size) {
+    snprintf(key, key_size, "%p", json);
+    if (hashtable_get(parents, key))
+        return -1;
+
+    return hashtable_set(parents, key, json_null());
+}
 
 /*** object ***/
 
 extern volatile uint32_t hashtable_seed;
 
-json_t *json_object(void)
-{
+json_t *json_object(void) {
     json_object_t *object = jsonp_malloc(sizeof(json_object_t));
-    if(!object)
+    if (!object)
         return NULL;
 
     if (!hashtable_seed) {
@@ -61,8 +69,7 @@ json_t *json_object(void)
 
     json_init(&object->json, JSON_OBJECT);
 
-    if(hashtable_init(&object->hashtable))
-    {
+    if (hashtable_init(&object->hashtable)) {
         jsonp_free(object);
         return NULL;
     }
@@ -70,50 +77,44 @@ json_t *json_object(void)
     return &object->json;
 }
 
-static void json_delete_object(json_object_t *object)
-{
+static void json_delete_object(json_object_t *object) {
     hashtable_close(&object->hashtable);
     jsonp_free(object);
 }
 
-size_t json_object_size(const json_t *json)
-{
+size_t json_object_size(const json_t *json) {
     json_object_t *object;
 
-    if(!json_is_object(json))
+    if (!json_is_object(json))
         return 0;
 
     object = json_to_object(json);
     return object->hashtable.size;
 }
 
-json_t *json_object_get(const json_t *json, const char *key)
-{
+json_t *json_object_get(const json_t *json, const char *key) {
     json_object_t *object;
 
-    if(!key || !json_is_object(json))
+    if (!key || !json_is_object(json))
         return NULL;
 
     object = json_to_object(json);
     return hashtable_get(&object->hashtable, key);
 }
 
-int json_object_set_new_nocheck(json_t *json, const char *key, json_t *value)
-{
+int json_object_set_new_nocheck(json_t *json, const char *key, json_t *value) {
     json_object_t *object;
 
-    if(!value)
+    if (!value)
         return -1;
 
-    if(!key || !json_is_object(json) || json == value)
-    {
+    if (!key || !json_is_object(json) || json == value) {
         json_decref(value);
         return -1;
     }
     object = json_to_object(json);
 
-    if(hashtable_set(&object->hashtable, key, value))
-    {
+    if (hashtable_set(&object->hashtable, key, value)) {
         json_decref(value);
         return -1;
     }
@@ -121,10 +122,8 @@ int json_object_set_new_nocheck(json_t *json, const char *key, json_t *value)
     return 0;
 }
 
-int json_object_set_new(json_t *json, const char *key, json_t *value)
-{
-    if(!key || !utf8_check_string(key, strlen(key)))
-    {
+int json_object_set_new(json_t *json, const char *key, json_t *value) {
+    if (!key || !utf8_check_string(key, strlen(key))) {
         json_decref(value);
         return -1;
     }
@@ -132,22 +131,20 @@ int json_object_set_new(json_t *json, const char *key, json_t *value)
     return json_object_set_new_nocheck(json, key, value);
 }
 
-int json_object_del(json_t *json, const char *key)
-{
+int json_object_del(json_t *json, const char *key) {
     json_object_t *object;
 
-    if(!key || !json_is_object(json))
+    if (!key || !json_is_object(json))
         return -1;
 
     object = json_to_object(json);
     return hashtable_del(&object->hashtable, key);
 }
 
-int json_object_clear(json_t *json)
-{
+int json_object_clear(json_t *json) {
     json_object_t *object;
 
-    if(!json_is_object(json))
+    if (!json_is_object(json))
         return -1;
 
     object = json_to_object(json);
@@ -156,107 +153,142 @@ int json_object_clear(json_t *json)
     return 0;
 }
 
-int json_object_update(json_t *object, json_t *other)
-{
+int json_object_update(json_t *object, json_t *other) {
     const char *key;
     json_t *value;
 
-    if(!json_is_object(object) || !json_is_object(other))
+    if (!json_is_object(object) || !json_is_object(other))
         return -1;
 
     json_object_foreach(other, key, value) {
-        if(json_object_set_nocheck(object, key, value))
+        if (json_object_set_nocheck(object, key, value))
             return -1;
     }
 
     return 0;
 }
 
-int json_object_update_existing(json_t *object, json_t *other)
-{
+int json_object_update_existing(json_t *object, json_t *other) {
     const char *key;
     json_t *value;
 
-    if(!json_is_object(object) || !json_is_object(other))
+    if (!json_is_object(object) || !json_is_object(other))
         return -1;
 
     json_object_foreach(other, key, value) {
-        if(json_object_get(object, key))
+        if (json_object_get(object, key))
             json_object_set_nocheck(object, key, value);
     }
 
     return 0;
 }
 
-int json_object_update_missing(json_t *object, json_t *other)
-{
+int json_object_update_missing(json_t *object, json_t *other) {
     const char *key;
     json_t *value;
 
-    if(!json_is_object(object) || !json_is_object(other))
+    if (!json_is_object(object) || !json_is_object(other))
         return -1;
 
     json_object_foreach(other, key, value) {
-        if(!json_object_get(object, key))
+        if (!json_object_get(object, key))
             json_object_set_nocheck(object, key, value);
     }
 
     return 0;
 }
 
-void *json_object_iter(json_t *json)
-{
+int do_object_update_recursive(json_t *object, json_t *other, hashtable_t *parents) {
+    const char *key;
+    json_t *value;
+    char loop_key[LOOP_KEY_LEN];
+    int res = 0;
+
+    if (!json_is_object(object) || !json_is_object(other))
+        return -1;
+
+    if (jsonp_loop_check(parents, other, loop_key, sizeof(loop_key)))
+        return -1;
+
+    json_object_foreach(other, key, value) {
+        json_t *v = json_object_get(object, key);
+
+        if (json_is_object(v) && json_is_object(value)) {
+            if (do_object_update_recursive(v, value, parents)) {
+                res = -1;
+                break;
+            }
+        } else {
+            if (json_object_set_nocheck(object, key, value)) {
+                res = -1;
+                break;
+            }
+        }
+    }
+
+    hashtable_del(parents, loop_key);
+
+    return res;
+}
+
+int json_object_update_recursive(json_t *object, json_t *other) {
+    int res;
+    hashtable_t parents_set;
+
+    if (hashtable_init(&parents_set))
+        return -1;
+    res = do_object_update_recursive(object, other, &parents_set);
+    hashtable_close(&parents_set);
+
+    return res;
+}
+
+void *json_object_iter(json_t *json) {
     json_object_t *object;
 
-    if(!json_is_object(json))
+    if (!json_is_object(json))
         return NULL;
 
     object = json_to_object(json);
     return hashtable_iter(&object->hashtable);
 }
 
-void *json_object_iter_at(json_t *json, const char *key)
-{
+void *json_object_iter_at(json_t *json, const char *key) {
     json_object_t *object;
 
-    if(!key || !json_is_object(json))
+    if (!key || !json_is_object(json))
         return NULL;
 
     object = json_to_object(json);
     return hashtable_iter_at(&object->hashtable, key);
 }
 
-void *json_object_iter_next(json_t *json, void *iter)
-{
+void *json_object_iter_next(json_t *json, void *iter) {
     json_object_t *object;
 
-    if(!json_is_object(json) || iter == NULL)
+    if (!json_is_object(json) || iter == NULL)
         return NULL;
 
     object = json_to_object(json);
     return hashtable_iter_next(&object->hashtable, iter);
 }
 
-const char *json_object_iter_key(void *iter)
-{
-    if(!iter)
+const char *json_object_iter_key(void *iter) {
+    if (!iter)
         return NULL;
 
     return hashtable_iter_key(iter);
 }
 
-json_t *json_object_iter_value(void *iter)
-{
-    if(!iter)
+json_t *json_object_iter_value(void *iter) {
+    if (!iter)
         return NULL;
 
     return (json_t *)hashtable_iter_value(iter);
 }
 
-int json_object_iter_set_new(json_t *json, void *iter, json_t *value)
-{
-    if(!json_is_object(json) || !iter || !value)
-    {
+int json_object_iter_set_new(json_t *json, void *iter, json_t *value) {
+    if (!json_is_object(json) || !iter || !value) {
         json_decref(value);
         return -1;
     }
@@ -265,81 +297,85 @@ int json_object_iter_set_new(json_t *json, void *iter, json_t *value)
     return 0;
 }
 
-void *json_object_key_to_iter(const char *key)
-{
-    if(!key)
+void *json_object_key_to_iter(const char *key) {
+    if (!key)
         return NULL;
 
     return hashtable_key_to_iter(key);
 }
 
-static int json_object_equal(const json_t *object1, const json_t *object2)
-{
+static int json_object_equal(const json_t *object1, const json_t *object2) {
     const char *key;
     const json_t *value1, *value2;
 
-    if(json_object_size(object1) != json_object_size(object2))
+    if (json_object_size(object1) != json_object_size(object2))
         return 0;
 
     json_object_foreach((json_t *)object1, key, value1) {
         value2 = json_object_get(object2, key);
 
-        if(!json_equal(value1, value2))
+        if (!json_equal(value1, value2))
             return 0;
     }
 
     return 1;
 }
 
-static json_t *json_object_copy(json_t *object)
-{
+static json_t *json_object_copy(json_t *object) {
     json_t *result;
 
     const char *key;
     json_t *value;
 
     result = json_object();
-    if(!result)
+    if (!result)
         return NULL;
 
-    json_object_foreach(object, key, value)
-        json_object_set_nocheck(result, key, value);
+    json_object_foreach(object, key, value) json_object_set_nocheck(result, key, value);
 
     return result;
 }
 
-static json_t *json_object_deep_copy(const json_t *object)
-{
+static json_t *json_object_deep_copy(const json_t *object, hashtable_t *parents) {
     json_t *result;
     void *iter;
+    char loop_key[LOOP_KEY_LEN];
+
+    if (jsonp_loop_check(parents, object, loop_key, sizeof(loop_key)))
+        return NULL;
 
     result = json_object();
-    if(!result)
-        return NULL;
+    if (!result)
+        goto out;
 
     /* Cannot use json_object_foreach because object has to be cast
        non-const */
     iter = json_object_iter((json_t *)object);
-    while(iter) {
+    while (iter) {
         const char *key;
         const json_t *value;
         key = json_object_iter_key(iter);
         value = json_object_iter_value(iter);
 
-        json_object_set_new_nocheck(result, key, json_deep_copy(value));
+        if (json_object_set_new_nocheck(result, key, do_deep_copy(value, parents))) {
+            json_decref(result);
+            result = NULL;
+            break;
+        }
         iter = json_object_iter_next((json_t *)object, iter);
     }
 
+out:
+    hashtable_del(parents, loop_key);
+
     return result;
 }
 
-
 /*** array ***/
 
-json_t *json_array(void)
-{
+json_t *json_array(void) {
     json_array_t *array = jsonp_malloc(sizeof(json_array_t));
-    if(!array)
+    if (!array)
         return NULL;
     json_init(&array->json, JSON_ARRAY);
 
@@ -347,7 +383,7 @@ json_t *json_array(void)
     array->size = 8;
 
     array->table = jsonp_malloc(array->size * sizeof(json_t *));
-    if(!array->table) {
+    if (!array->table) {
         jsonp_free(array);
         return NULL;
     }
@@ -355,54 +391,48 @@ json_t *json_array(void)
     return &array->json;
 }
 
-static void json_delete_array(json_array_t *array)
-{
+static void json_delete_array(json_array_t *array) {
     size_t i;
 
-    for(i = 0; i < array->entries; i++)
+    for (i = 0; i < array->entries; i++)
         json_decref(array->table[i]);
 
     jsonp_free(array->table);
     jsonp_free(array);
 }
 
-size_t json_array_size(const json_t *json)
-{
-    if(!json_is_array(json))
+size_t json_array_size(const json_t *json) {
+    if (!json_is_array(json))
         return 0;
 
     return json_to_array(json)->entries;
 }
 
-json_t *json_array_get(const json_t *json, size_t index)
-{
+json_t *json_array_get(const json_t *json, size_t index) {
     json_array_t *array;
-    if(!json_is_array(json))
+    if (!json_is_array(json))
         return NULL;
     array = json_to_array(json);
 
-    if(index >= array->entries)
+    if (index >= array->entries)
         return NULL;
 
     return array->table[index];
 }
 
-int json_array_set_new(json_t *json, size_t index, json_t *value)
-{
+int json_array_set_new(json_t *json, size_t index, json_t *value) {
     json_array_t *array;
 
-    if(!value)
+    if (!value)
         return -1;
 
-    if(!json_is_array(json) || json == value)
-    {
+    if (!json_is_array(json) || json == value) {
         json_decref(value);
         return -1;
     }
     array = json_to_array(json);
 
-    if(index >= array->entries)
-    {
+    if (index >= array->entries) {
         json_decref(value);
         return -1;
     }
@@ -413,40 +443,33 @@ int json_array_set_new(json_t *json, size_t index, json_t *value)
     return 0;
 }
 
-static void array_move(json_array_t *array, size_t dest,
-                       size_t src, size_t count)
-{
+static void array_move(json_array_t *array, size_t dest, size_t src, size_t count) {
     memmove(&array->table[dest], &array->table[src], count * sizeof(json_t *));
 }
 
-static void array_copy(json_t **dest, size_t dpos,
-                       json_t **src, size_t spos,
-                       size_t count)
-{
+static void array_copy(json_t **dest, size_t dpos, json_t **src, size_t spos,
+                       size_t count) {
     memcpy(&dest[dpos], &src[spos], count * sizeof(json_t *));
 }
 
-static json_t **json_array_grow(json_array_t *array,
-                                size_t amount,
-                                int copy)
-{
+static json_t **json_array_grow(json_array_t *array, size_t amount, int copy) {
     size_t new_size;
     json_t **old_table, **new_table;
 
-    if(array->entries + amount <= array->size)
+    if (array->entries + amount <= array->size)
         return array->table;
 
     old_table = array->table;
 
     new_size = max(array->size + amount, array->size * 2);
     new_table = jsonp_malloc(new_size * sizeof(json_t *));
-    if(!new_table)
+    if (!new_table)
         return NULL;
 
     array->size = new_size;
     array->table = new_table;
 
-    if(copy) {
+    if (copy) {
         array_copy(array->table, 0, old_table, 0, array->entries);
         jsonp_free(old_table);
         return array->table;
@@ -455,21 +478,19 @@ static json_t **json_array_grow(json_array_t *array,
     return old_table;
 }
 
-int json_array_append_new(json_t *json, json_t *value)
-{
+int json_array_append_new(json_t *json, json_t *value) {
     json_array_t *array;
 
-    if(!value)
+    if (!value)
         return -1;
 
-    if(!json_is_array(json) || json == value)
-    {
+    if (!json_is_array(json) || json == value) {
         json_decref(value);
         return -1;
     }
     array = json_to_array(json);
 
-    if(!json_array_grow(array, 1, 1)) {
+    if (!json_array_grow(array, 1, 1)) {
         json_decref(value);
         return -1;
     }
@@ -480,38 +501,35 @@ int json_array_append_new(json_t *json, json_t *value)
     return 0;
 }
 
-int json_array_insert_new(json_t *json, size_t index, json_t *value)
-{
+int json_array_insert_new(json_t *json, size_t index, json_t *value) {
     json_array_t *array;
     json_t **old_table;
 
-    if(!value)
+    if (!value)
         return -1;
 
-    if(!json_is_array(json) || json == value) {
+    if (!json_is_array(json) || json == value) {
         json_decref(value);
         return -1;
     }
     array = json_to_array(json);
 
-    if(index > array->entries) {
+    if (index > array->entries) {
         json_decref(value);
         return -1;
     }
 
     old_table = json_array_grow(array, 1, 0);
-    if(!old_table) {
+    if (!old_table) {
         json_decref(value);
         return -1;
     }
 
-    if(old_table != array->table) {
+    if (old_table != array->table) {
         array_copy(array->table, 0, old_table, 0, index);
-        array_copy(array->table, index + 1, old_table, index,
-                   array->entries - index);
+        array_copy(array->table, index + 1, old_table, index, array->entries - index);
         jsonp_free(old_table);
-    }
-    else
+    } else
         array_move(array, index + 1, index, array->entries - index);
 
     array->table[index] = value;
@@ -520,21 +538,20 @@ int json_array_insert_new(json_t *json, size_t index, json_t *value)
     return 0;
 }
 
-int json_array_remove(json_t *json, size_t index)
-{
+int json_array_remove(json_t *json, size_t index) {
     json_array_t *array;
 
-    if(!json_is_array(json))
+    if (!json_is_array(json))
         return -1;
     array = json_to_array(json);
 
-    if(index >= array->entries)
+    if (index >= array->entries)
         return -1;
 
     json_decref(array->table[index]);
 
     /* If we're removing the last element, nothing has to be moved */
-    if(index < array->entries - 1)
+    if (index < array->entries - 1)
         array_move(array, index, index + 1, array->entries - index - 1);
 
     array->entries--;
@@ -542,36 +559,34 @@ int json_array_remove(json_t *json, size_t index)
     return 0;
 }
 
-int json_array_clear(json_t *json)
-{
+int json_array_clear(json_t *json) {
     json_array_t *array;
     size_t i;
 
-    if(!json_is_array(json))
+    if (!json_is_array(json))
         return -1;
     array = json_to_array(json);
 
-    for(i = 0; i < array->entries; i++)
+    for (i = 0; i < array->entries; i++)
         json_decref(array->table[i]);
 
     array->entries = 0;
     return 0;
 }
 
-int json_array_extend(json_t *json, json_t *other_json)
-{
+int json_array_extend(json_t *json, json_t *other_json) {
     json_array_t *array, *other;
     size_t i;
 
-    if(!json_is_array(json) || !json_is_array(other_json))
+    if (!json_is_array(json) || !json_is_array(other_json))
         return -1;
     array = json_to_array(json);
     other = json_to_array(other_json);
 
-    if(!json_array_grow(array, other->entries, 1))
+    if (!json_array_grow(array, other->entries, 1))
         return -1;
 
-    for(i = 0; i < other->entries; i++)
+    for (i = 0; i < other->entries; i++)
         json_incref(other->table[i]);
 
     array_copy(array->table, array->entries, other->table, 0, other->entries);
@@ -580,80 +595,87 @@ int json_array_extend(json_t *json, json_t *other_json)
     return 0;
 }
 
-static int json_array_equal(const json_t *array1, const json_t *array2)
-{
+static int json_array_equal(const json_t *array1, const json_t *array2) {
     size_t i, size;
 
     size = json_array_size(array1);
-    if(size != json_array_size(array2))
+    if (size != json_array_size(array2))
         return 0;
 
-    for(i = 0; i < size; i++)
-    {
+    for (i = 0; i < size; i++) {
         json_t *value1, *value2;
 
         value1 = json_array_get(array1, i);
         value2 = json_array_get(array2, i);
 
-        if(!json_equal(value1, value2))
+        if (!json_equal(value1, value2))
             return 0;
     }
 
     return 1;
 }
 
-static json_t *json_array_copy(json_t *array)
-{
+static json_t *json_array_copy(json_t *array) {
     json_t *result;
     size_t i;
 
     result = json_array();
-    if(!result)
+    if (!result)
         return NULL;
 
-    for(i = 0; i < json_array_size(array); i++)
+    for (i = 0; i < json_array_size(array); i++)
         json_array_append(result, json_array_get(array, i));
 
     return result;
 }
 
-static json_t *json_array_deep_copy(const json_t *array)
-{
+static json_t *json_array_deep_copy(const json_t *array, hashtable_t *parents) {
     json_t *result;
     size_t i;
+    char loop_key[LOOP_KEY_LEN];
 
-    result = json_array();
-    if(!result)
+    if (jsonp_loop_check(parents, array, loop_key, sizeof(loop_key)))
         return NULL;
 
-    for(i = 0; i < json_array_size(array); i++)
-        json_array_append_new(result, json_deep_copy(json_array_get(array, i)));
+    result = json_array();
+    if (!result)
+        goto out;
+
+    for (i = 0; i < json_array_size(array); i++) {
+        if (json_array_append_new(result,
+                                  do_deep_copy(json_array_get(array, i), parents))) {
+            json_decref(result);
+            result = NULL;
+            break;
+        }
+    }
+
+out:
+    hashtable_del(parents, loop_key);
 
     return result;
 }
 
 /*** string ***/
 
-static json_t *string_create(const char *value, size_t len, int own)
-{
+static json_t *string_create(const char *value, size_t len, int own) {
     char *v;
     json_string_t *string;
 
-    if(!value)
+    if (!value)
         return NULL;
 
-    if(own)
+    if (own)
         v = (char *)value;
     else {
         v = jsonp_strndup(value, len);
-        if(!v)
+        if (!v)
             return NULL;
     }
 
     string = jsonp_malloc(sizeof(json_string_t));
-    if(!string) {
-        if(!own)
-            jsonp_free(v);
+    if (!string) {
+        jsonp_free(v);
         return NULL;
     }
     json_init(&string->json, JSON_STRING);
@@ -663,75 +685,66 @@ static json_t *string_create(const char *value, size_t len, int own)
     return &string->json;
 }
 
-json_t *json_string_nocheck(const char *value)
-{
-    if(!value)
+json_t *json_string_nocheck(const char *value) {
+    if (!value)
         return NULL;
 
     return string_create(value, strlen(value), 0);
 }
 
-json_t *json_stringn_nocheck(const char *value, size_t len)
-{
+json_t *json_stringn_nocheck(const char *value, size_t len) {
     return string_create(value, len, 0);
 }
 
 /* this is private; "steal" is not a public API concept */
-json_t *jsonp_stringn_nocheck_own(const char *value, size_t len)
-{
+json_t *jsonp_stringn_nocheck_own(const char *value, size_t len) {
     return string_create(value, len, 1);
 }
 
-json_t *json_string(const char *value)
-{
-    if(!value)
+json_t *json_string(const char *value) {
+    if (!value)
         return NULL;
 
     return json_stringn(value, strlen(value));
 }
 
-json_t *json_stringn(const char *value, size_t len)
-{
-    if(!value || !utf8_check_string(value, len))
+json_t *json_stringn(const char *value, size_t len) {
+    if (!value || !utf8_check_string(value, len))
         return NULL;
 
     return json_stringn_nocheck(value, len);
 }
 
-const char *json_string_value(const json_t *json)
-{
-    if(!json_is_string(json))
+const char *json_string_value(const json_t *json) {
+    if (!json_is_string(json))
         return NULL;
 
     return json_to_string(json)->value;
 }
 
-size_t json_string_length(const json_t *json)
-{
-    if(!json_is_string(json))
+size_t json_string_length(const json_t *json) {
+    if (!json_is_string(json))
         return 0;
 
     return json_to_string(json)->length;
 }
 
-int json_string_set_nocheck(json_t *json, const char *value)
-{
-    if(!value)
+int json_string_set_nocheck(json_t *json, const char *value) {
+    if (!value)
         return -1;
 
     return json_string_setn_nocheck(json, value, strlen(value));
 }
 
-int json_string_setn_nocheck(json_t *json, const char *value, size_t len)
-{
+int json_string_setn_nocheck(json_t *json, const char *value, size_t len) {
     char *dup;
     json_string_t *string;
 
-    if(!json_is_string(json) || !value)
+    if (!json_is_string(json) || !value)
         return -1;
 
     dup = jsonp_strndup(value, len);
-    if(!dup)
+    if (!dup)
         return -1;
 
     string = json_to_string(json);
@@ -742,72 +755,68 @@ int json_string_setn_nocheck(json_t *json, const char *value, size_t len)
     return 0;
 }
 
-int json_string_set(json_t *json, const char *value)
-{
-    if(!value)
+int json_string_set(json_t *json, const char *value) {
+    if (!value)
         return -1;
 
     return json_string_setn(json, value, strlen(value));
 }
 
-int json_string_setn(json_t *json, const char *value, size_t len)
-{
-    if(!value || !utf8_check_string(value, len))
+int json_string_setn(json_t *json, const char *value, size_t len) {
+    if (!value || !utf8_check_string(value, len))
         return -1;
 
     return json_string_setn_nocheck(json, value, len);
 }
 
-static void json_delete_string(json_string_t *string)
-{
+static void json_delete_string(json_string_t *string) {
     jsonp_free(string->value);
     jsonp_free(string);
 }
 
-static int json_string_equal(const json_t *string1, const json_t *string2)
-{
+static int json_string_equal(const json_t *string1, const json_t *string2) {
     json_string_t *s1, *s2;
 
-    if(!json_is_string(string1) || !json_is_string(string2))
-        return 0;
-
     s1 = json_to_string(string1);
     s2 = json_to_string(string2);
     return s1->length == s2->length && !memcmp(s1->value, s2->value, s1->length);
 }
 
-static json_t *json_string_copy(const json_t *string)
-{
+static json_t *json_string_copy(const json_t *string) {
     json_string_t *s;
 
-    if(!json_is_string(string))
-        return NULL;
-
     s = json_to_string(string);
     return json_stringn_nocheck(s->value, s->length);
 }
 
 json_t *json_vsprintf(const char *fmt, va_list ap) {
+    json_t *json = NULL;
     int length;
     char *buf;
     va_list aq;
     va_copy(aq, ap);
 
     length = vsnprintf(NULL, 0, fmt, ap);
-    if (length == 0)
-        return json_string("");
+    if (length == 0) {
+        json = json_string("");
+        goto out;
+    }
 
     buf = jsonp_malloc(length + 1);
     if (!buf)
-        return NULL;
+        goto out;
 
     vsnprintf(buf, length + 1, fmt, aq);
     if (!utf8_check_string(buf, length)) {
         jsonp_free(buf);
-        return NULL;
+        goto out;
     }
 
-    return jsonp_stringn_nocheck_own(buf, length);
+    json = jsonp_stringn_nocheck_own(buf, length);
+
+out:
+    va_end(aq);
+    return json;
 }
 
 json_t *json_sprintf(const char *fmt, ...) {
@@ -821,13 +830,11 @@ json_t *json_sprintf(const char *fmt, ...) {
     return result;
 }
 
-
 /*** integer ***/
 
-json_t *json_integer(json_int_t value)
-{
+json_t *json_integer(json_int_t value) {
     json_integer_t *integer = jsonp_malloc(sizeof(json_integer_t));
-    if(!integer)
+    if (!integer)
         return NULL;
     json_init(&integer->json, JSON_INTEGER);
 
@@ -835,17 +842,15 @@ json_t *json_integer(json_int_t value)
     return &integer->json;
 }
 
-json_int_t json_integer_value(const json_t *json)
-{
-    if(!json_is_integer(json))
+json_int_t json_integer_value(const json_t *json) {
+    if (!json_is_integer(json))
         return 0;
 
     return json_to_integer(json)->value;
 }
 
-int json_integer_set(json_t *json, json_int_t value)
-{
-    if(!json_is_integer(json))
+int json_integer_set(json_t *json, json_int_t value) {
+    if (!json_is_integer(json))
         return -1;
 
     json_to_integer(json)->value = value;
@@ -853,33 +858,26 @@ int json_integer_set(json_t *json, json_int_t value)
     return 0;
 }
 
-static void json_delete_integer(json_integer_t *integer)
-{
-    jsonp_free(integer);
-}
+static void json_delete_integer(json_integer_t *integer) { jsonp_free(integer); }
 
-static int json_integer_equal(const json_t *integer1, const json_t *integer2)
-{
+static int json_integer_equal(const json_t *integer1, const json_t *integer2) {
     return json_integer_value(integer1) == json_integer_value(integer2);
 }
 
-static json_t *json_integer_copy(const json_t *integer)
-{
+static json_t *json_integer_copy(const json_t *integer) {
     return json_integer(json_integer_value(integer));
 }
 
-
 /*** real ***/
 
-json_t *json_real(double value)
-{
+json_t *json_real(double value) {
     json_real_t *real;
 
-    if(isnan(value) || isinf(value))
+    if (isnan(value) || isinf(value))
         return NULL;
 
     real = jsonp_malloc(sizeof(json_real_t));
-    if(!real)
+    if (!real)
         return NULL;
     json_init(&real->json, JSON_REAL);
 
@@ -887,17 +885,15 @@ json_t *json_real(double value)
     return &real->json;
 }
 
-double json_real_value(const json_t *json)
-{
-    if(!json_is_real(json))
+double json_real_value(const json_t *json) {
+    if (!json_is_real(json))
         return 0;
 
     return json_to_real(json)->value;
 }
 
-int json_real_set(json_t *json, double value)
-{
-    if(!json_is_real(json) || isnan(value) || isinf(value))
+int json_real_set(json_t *json, double value) {
+    if (!json_is_real(json) || isnan(value) || isinf(value))
         return -1;
 
     json_to_real(json)->value = value;
@@ -905,66 +901,51 @@ int json_real_set(json_t *json, double value)
     return 0;
 }
 
-static void json_delete_real(json_real_t *real)
-{
-    jsonp_free(real);
-}
+static void json_delete_real(json_real_t *real) { jsonp_free(real); }
 
-static int json_real_equal(const json_t *real1, const json_t *real2)
-{
+static int json_real_equal(const json_t *real1, const json_t *real2) {
     return json_real_value(real1) == json_real_value(real2);
 }
 
-static json_t *json_real_copy(const json_t *real)
-{
+static json_t *json_real_copy(const json_t *real) {
     return json_real(json_real_value(real));
 }
 
-
 /*** number ***/
 
-double json_number_value(const json_t *json)
-{
-    if(json_is_integer(json))
+double json_number_value(const json_t *json) {
+    if (json_is_integer(json))
         return (double)json_integer_value(json);
-    else if(json_is_real(json))
+    else if (json_is_real(json))
         return json_real_value(json);
     else
         return 0.0;
 }
 
-
 /*** simple values ***/
 
-json_t *json_true(void)
-{
+json_t *json_true(void) {
     static json_t the_true = {JSON_TRUE, (size_t)-1};
     return &the_true;
 }
 
-
-json_t *json_false(void)
-{
+json_t *json_false(void) {
     static json_t the_false = {JSON_FALSE, (size_t)-1};
     return &the_false;
 }
 
-
-json_t *json_null(void)
-{
+json_t *json_null(void) {
     static json_t the_null = {JSON_NULL, (size_t)-1};
     return &the_null;
 }
 
-
 /*** deletion ***/
 
-void json_delete(json_t *json)
-{
+void json_delete(json_t *json) {
     if (!json)
         return;
 
-    switch(json_typeof(json)) {
+    switch (json_typeof(json)) {
         case JSON_OBJECT:
             json_delete_object(json_to_object(json));
             break;
@@ -987,22 +968,20 @@ void json_delete(json_t *json)
     /* json_delete is not called for true, false or null */
 }
 
-
 /*** equality ***/
 
-int json_equal(const json_t *json1, const json_t *json2)
-{
-    if(!json1 || !json2)
+int json_equal(const json_t *json1, const json_t *json2) {
+    if (!json1 || !json2)
         return 0;
 
-    if(json_typeof(json1) != json_typeof(json2))
+    if (json_typeof(json1) != json_typeof(json2))
         return 0;
 
     /* this covers true, false and null as they are singletons */
-    if(json1 == json2)
+    if (json1 == json2)
         return 1;
 
-    switch(json_typeof(json1)) {
+    switch (json_typeof(json1)) {
         case JSON_OBJECT:
             return json_object_equal(json1, json2);
         case JSON_ARRAY:
@@ -1018,15 +997,13 @@ int json_equal(const json_t *json1, const json_t *json2)
     }
 }
 
-
 /*** copying ***/
 
-json_t *json_copy(json_t *json)
-{
-    if(!json)
+json_t *json_copy(json_t *json) {
+    if (!json)
         return NULL;
 
-    switch(json_typeof(json)) {
+    switch (json_typeof(json)) {
         case JSON_OBJECT:
             return json_object_copy(json);
         case JSON_ARRAY:
@@ -1044,20 +1021,29 @@ json_t *json_copy(json_t *json)
         default:
             return NULL;
     }
-
-    return NULL;
 }
 
-json_t *json_deep_copy(const json_t *json)
-{
-    if(!json)
+json_t *json_deep_copy(const json_t *json) {
+    json_t *res;
+    hashtable_t parents_set;
+
+    if (hashtable_init(&parents_set))
+        return NULL;
+    res = do_deep_copy(json, &parents_set);
+    hashtable_close(&parents_set);
+
+    return res;
+}
+
+json_t *do_deep_copy(const json_t *json, hashtable_t *parents) {
+    if (!json)
         return NULL;
 
-    switch(json_typeof(json)) {
+    switch (json_typeof(json)) {
         case JSON_OBJECT:
-            return json_object_deep_copy(json);
+            return json_object_deep_copy(json, parents);
         case JSON_ARRAY:
-            return json_array_deep_copy(json);
+            return json_array_deep_copy(json, parents);
             /* for the rest of the types, deep copying doesn't differ from
                shallow copying */
         case JSON_STRING:
@@ -1073,6 +1059,4 @@ json_t *json_deep_copy(const json_t *json)
         default:
             return NULL;
     }
-
-    return NULL;
 }
