@@ -5,9 +5,9 @@
  * it under the terms of the MIT license. See LICENSE for details.
  */
 
-#include <math.h>
-#include <jansson.h>
 #include "util.h"
+#include <jansson.h>
+#include <math.h>
 
 #ifdef INFINITY
 // This test triggers "warning C4756: overflow in constant arithmetic"
@@ -15,20 +15,19 @@
 // (This can only be done on function level so we keep these tests separate)
 #ifdef _MSC_VER
 #pragma warning(push)
-#pragma warning (disable: 4756)
+#pragma warning(disable : 4756)
 #endif
-static void test_inifity()
-{
+static void test_inifity() {
     json_t *real = json_real(INFINITY);
     if (real != NULL)
-       fail("could construct a real from Inf");
+        fail("could construct a real from Inf");
 
     real = json_real(1.0);
     if (json_real_set(real, INFINITY) != -1)
-	    fail("could set a real to Inf");
+        fail("could set a real to Inf");
 
     if (json_real_value(real) != 1.0)
-       fail("real value changed unexpectedly");
+        fail("real value changed unexpectedly");
 
     json_decref(real);
 #ifdef _MSC_VER
@@ -37,33 +36,32 @@ static void test_inifity()
 }
 #endif // INFINITY
 
-static void test_bad_args(void)
-{
+static void test_bad_args(void) {
     json_t *txt = json_string("test");
 
-    if(json_integer_value(NULL) != 0)
+    if (json_integer_value(NULL) != 0)
         fail("json_integer_value did not return 0 for non-integer");
-    if(json_integer_value(txt) != 0)
+    if (json_integer_value(txt) != 0)
         fail("json_integer_value did not return 0 for non-integer");
 
-    if(!json_integer_set(NULL, 0))
+    if (!json_integer_set(NULL, 0))
         fail("json_integer_set did not return error for non-integer");
-    if(!json_integer_set(txt, 0))
+    if (!json_integer_set(txt, 0))
         fail("json_integer_set did not return error for non-integer");
 
-    if(json_real_value(NULL) != 0.0)
+    if (json_real_value(NULL) != 0.0)
         fail("json_real_value did not return 0.0 for non-real");
-    if(json_real_value(txt) != 0.0)
+    if (json_real_value(txt) != 0.0)
         fail("json_real_value did not return 0.0 for non-real");
 
-    if(!json_real_set(NULL, 0.0))
+    if (!json_real_set(NULL, 0.0))
         fail("json_real_set did not return error for non-real");
-    if(!json_real_set(txt, 0.0))
+    if (!json_real_set(txt, 0.0))
         fail("json_real_set did not return error for non-real");
 
-    if(json_number_value(NULL) != 0.0)
+    if (json_number_value(NULL) != 0.0)
         fail("json_number_value did not return 0.0 for non-numeric");
-    if(json_number_value(txt) != 0.0)
+    if (json_number_value(txt) != 0.0)
         fail("json_number_value did not return 0.0 for non-numeric");
 
     if (txt->refcount != 1)
@@ -72,8 +70,7 @@ static void test_bad_args(void)
     json_decref(txt);
 }
 
-static void run_tests()
-{
+static void run_tests() {
     json_t *integer, *real;
     json_int_t i;
     double d;
@@ -81,24 +78,24 @@ static void run_tests()
     integer = json_integer(5);
     real = json_real(100.1);
 
-    if(!integer)
+    if (!integer)
         fail("unable to create integer");
-    if(!real)
+    if (!real)
         fail("unable to create real");
 
     i = json_integer_value(integer);
-    if(i != 5)
+    if (i != 5)
         fail("wrong integer value");
 
     d = json_real_value(real);
-    if(d != 100.1)
+    if (d != 100.1)
         fail("wrong real value");
 
     d = json_number_value(integer);
-    if(d != 5.0)
+    if (d != 5.0)
         fail("wrong number value");
     d = json_number_value(real);
-    if(d != 100.1)
+    if (d != 100.1)
         fail("wrong number value");
 
     json_decref(integer);
@@ -106,14 +103,14 @@ static void run_tests()
 
 #ifdef NAN
     real = json_real(NAN);
-    if(real != NULL)
+    if (real != NULL)
         fail("could construct a real from NaN");
 
     real = json_real(1.0);
-    if(json_real_set(real, NAN) != -1)
+    if (json_real_set(real, NAN) != -1)
         fail("could set a real to NaN");
 
-    if(json_real_value(real) != 1.0)
+    if (json_real_value(real) != 1.0)
         fail("real value changed unexpectedly");
 
     json_decref(real);
